@@ -227,6 +227,7 @@ impl Crate {
     fn check_wasm_pack_latest_version() -> Result<Crate> {
         let url = "https://crates.io/api/v1/crates/wasm-pack";
         let agent = ureq::builder()
+            .try_proxy_from_env(true)
             .user_agent(&format!(
                 "wasm-pack/{} ({})",
                 WASM_PACK_VERSION.unwrap_or_else(|| "unknown"),
@@ -722,6 +723,7 @@ impl CrateData {
 
         NpmPackage::ESModulesPackage(ESModulesPackage {
             name: data.name,
+            ty: "module".into(),
             collaborators: pkg.authors.clone(),
             description: self.pkg().description.clone(),
             version: pkg.version.to_string(),
@@ -731,7 +733,7 @@ impl CrateData {
                 url: repo_url,
             }),
             files: data.files,
-            module: data.main.clone(),
+            main: data.main.clone(),
             homepage: data.homepage,
             types: data.dts_file,
             side_effects: vec![format!("./{}", data.main), "./snippets/*".to_owned()],
@@ -754,6 +756,7 @@ impl CrateData {
 
         NpmPackage::ESModulesPackage(ESModulesPackage {
             name: data.name,
+            ty: "module".into(),
             collaborators: pkg.authors.clone(),
             description: self.pkg().description.clone(),
             version: pkg.version.to_string(),
@@ -763,7 +766,7 @@ impl CrateData {
                 url: repo_url,
             }),
             files: data.files,
-            module: data.main,
+            main: data.main,
             homepage: data.homepage,
             types: data.dts_file,
             side_effects: vec!["./snippets/*".to_owned()],
